function create_whitenoise_images(width, height)
    % Load Linear Gray ICC profile data
    fp = fopen('LinearGray.icc');
    icc_profile_data = cast(fread(fp), 'uint8');
    fclose(fp);

    % Create a struct containing the TIFF tags for all images
    tags = struct();
    tags.ImageLength = height;
    tags.ImageWidth = width;
    tags.Photometric = Tiff.Photometric.MinIsBlack;
    tags.BitsPerSample = 8;
    tags.SamplesPerPixel = 1;
    tags.PlanarConfiguration = Tiff.PlanarConfiguration.Chunky;
    tags.Compression = Tiff.Compression.None;
    tags.ICCProfile = icc_profile_data;

    % Seed random number generator using the current time.  Otherwise, we'll
    % get the same sequence of random numbers in every MATLAB session.
    rng('shuffle');

    while 1
        % Read filename from standard input
        filename = input('', 's');

        % If the filename is empty, we're done
        if length(filename) == 0
            break
        end

        % Read grain size from standard input
        grain_size = sscanf(input('', 's'), '%d');

        % Generate noise
        pixels = randi([0, 255], round(height/grain_size), round(width/grain_size), 'uint8');

        % Resize noise to required dimensions
        if ~isequal(size(pixels), [height, width])
            pixels = imresize(pixels, [height, width], 'nearest');
        end

        % Save noise as TIFF image
        img = Tiff(filename, 'w');
        setTag(img, tags);
        write(img, pixels);
        close(img);

        % Write the filename to standard output to signal completion
        fprintf('%s\n', filename);
    end
end
