import os
import subprocess
import time


# Absolute path to the directory where the white noise images are stored
imagepath = '/Users/cstawarz/Documents/Work/UserTemplates/Yvonne/experiment1/whitenoise_images'

# In order for MWorks to access the white noise image directory, we need to
# create a symbolic link to it inside the current working directory
imagedir = os.path.basename(imagepath)
os.symlink(imagepath, imagedir)

# Name of the subdirectory for the current session (date and time stamp)
sessiondir = time.strftime('%Y%m%d-%H%M%S')

# Image parameters
num_images = int(getvar('num_noise_frames'))
image_width = getvar('dynamic_white_noise_frame_width')
image_height = getvar('dynamic_white_noise_frame_height')

# Persistent MATLAB process for generating noise images
matlab_args = [
    '/Applications/MATLAB_R2018a.app/bin/matlab',
    '-nodisplay',
    '-nojvm',
    '-r', 'create_whitenoise_images(%d, %d)' % (image_width, image_height),
    ]
matlab = subprocess.Popen(matlab_args,
                          stdin = subprocess.PIPE,
                          stdout = subprocess.PIPE)


def generate_whitenoise_images():
    # Create a per-trial subdirectory inside the session directory
    trialdir = 'trial_%05d' % getvar('trial_number')
    trialpath = os.path.join(imagedir, sessiondir, trialdir)
    os.makedirs(trialpath)

    grain_size = getvar('dynamic_white_noise_grain_size')
    filenames = []

    # Generate the images using MATLAB
    for i in range(num_images):
        filename = os.path.join(trialpath, 'frame_%03d.tiff' % (i + 1))
        matlab.stdin.write('%s\n%d\n' % (filename, grain_size))
        while matlab.stdout.readline().strip() != filename:
            pass
        filenames.append(filename)

    setvar('dynamic_white_noise_filenames', filenames)
